"use strict";

/**
 * Usage:
 *
 * // gatsby-config.js
 * plugins: [
 *  `gatsby-plugin-stylus`,
 * ],
 *
 * // Usage with options:
 *
 * // gatsby-config.js
 * plugins: [
 *   {
 *     resolve: `gatsby-plugin-stylus`,
 *     options: {
 *       use: [],
 *       import: []
 *     },
 *   },
 * ],
 */

const resolve = require(`./resolve`);
exports.onCreateWebpackConfig = ({
  actions,
  stage,
  loaders
}, {
  cssLoaderOptions = {},
  postCssPlugins,
  ...stylusOptions
}) => {
  var _cssLoaderOptions$mod, _cssLoaderOptions$mod2, _cssLoaderOptions$mod3;
  const isSSR = [`develop-html`, `build-html`].includes(stage);
  const {
    setWebpackConfig
  } = actions;
  const stylusLoader = {
    loader: resolve(`stylus-loader`),
    options: {
      ...stylusOptions
    }
  };
  const stylusRule = {
    test: /\.styl$/,
    use: isSSR ? [loaders.null()] : [loaders.miniCssExtract(), loaders.css({
      importLoaders: 2,
      ...cssLoaderOptions,
      modules: false
    }), loaders.postcss({
      plugins: postCssPlugins
    }), stylusLoader]
  };
  const stylusRuleModules = {
    test: /\.module\.styl$/,
    use: [!isSSR && loaders.miniCssExtract({
      modules: {
        namedExport: (_cssLoaderOptions$mod = (_cssLoaderOptions$mod2 = cssLoaderOptions.modules) === null || _cssLoaderOptions$mod2 === void 0 ? void 0 : _cssLoaderOptions$mod2.namedExport) !== null && _cssLoaderOptions$mod !== void 0 ? _cssLoaderOptions$mod : true
      }
    }), loaders.css({
      ...cssLoaderOptions,
      importLoaders: 1,
      modules: (_cssLoaderOptions$mod3 = cssLoaderOptions.modules) !== null && _cssLoaderOptions$mod3 !== void 0 ? _cssLoaderOptions$mod3 : true
    }), loaders.postcss({
      plugins: postCssPlugins
    }), stylusLoader].filter(Boolean)
  };
  const configRules = [{
    oneOf: [stylusRuleModules, stylusRule]
  }];
  setWebpackConfig({
    module: {
      rules: configRules
    }
  });
};